DateFormatter class

Locale-aware date formatter used by all built-in templates.

Constructors

DateFormatter({String format = 'MMM dd, yyyy', String? locale})
const

Properties

format String
final
hashCode int
The hash code for this object.
no setterinherited
locale String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatDate(DateTime date) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited