InvoiceColumn class

Configuration for a single column in the invoice table.

Constructors

InvoiceColumn({required String id, required String header, double flex = 1.0, Alignment alignment = pw.Alignment.centerLeft, String formatter(InvoiceItem)?})
InvoiceColumn.description()
factory
InvoiceColumn.discount()
factory
InvoiceColumn.index()
factory
InvoiceColumn.itemCode()
factory
InvoiceColumn.quantity()
factory
InvoiceColumn.tax()
factory
InvoiceColumn.total()
factory
InvoiceColumn.unit()
factory
InvoiceColumn.unitPrice()
factory

Properties

alignment → Alignment
final
flex double
final
formatter String Function(InvoiceItem)?
final
hashCode int
The hash code for this object.
no setterinherited
final
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? header, double? flex, Alignment? alignment, Object? formatter = copyWithUnset}) InvoiceColumn
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultColumns List<InvoiceColumn>
Default columns for a standard invoice
no setter
simpleColumns List<InvoiceColumn>
Simple columns for a basic invoice
no setter