InvoiceTotals class

Authoritative rounded totals for a complete document.

Constructors

InvoiceTotals({required double subtotal, required double discount, required double taxableSubtotal, required double tax, required double lineTotal, required List<CalculatedInvoiceAdjustment> adjustments, required double adjustmentDiscount, required double shipping, required double fees, required double withholding, required double grandTotal, required double amountPaid, required double balanceDue})

Properties

adjustmentDiscount double
final
adjustments List<CalculatedInvoiceAdjustment>
final
amountPaid double
final
balanceDue double
final
discount double
final
fees double
final
grandTotal double
final
hashCode int
The hash code for this object.
no setterinherited
lineTotal double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shipping double
final
subtotal double
final
tax double
final
taxableSubtotal double
final
withholding double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited