InvoiceStyle class
Master visual, formatting, locale, and font configuration.
Constructors
-
InvoiceStyle({PdfColor primaryColor = PdfColors.blue800, PdfColor secondaryColor = PdfColors.blueGrey800, PdfColor accentColor = PdfColors.amber, PdfColor backgroundColor = PdfColors.white, PdfColor textColor = PdfColors.grey900, PdfColor mutedTextColor = PdfColors.grey600, Font? primaryFont, Font? boldFont, Font? italicFont, List<
Font> fontFallback = const [], double titleFontSize = 24, double subtitleFontSize = 14, double bodyFontSize = 10, double smallFontSize = 8, PdfPageFormat pageFormat = PdfPageFormat.a4, EdgeInsets pageMargin = const pw.EdgeInsets.all(40), HeaderStyle? headerStyle, TableStyle? tableStyle, String? watermarkText, Uint8List? watermarkImage, double watermarkOpacity = 0.06, double watermarkAngle = -0.5, Uint8List? signatureImage, String? signatureLabel, InvoiceLocalization? localization, MonetaryPolicy monetaryPolicy = MonetaryPolicy.standard, Map<String, String> ? labels}) - InvoiceStyle.classic()
-
factory
- InvoiceStyle.colorful()
-
factory
- InvoiceStyle.dark()
-
factory
- InvoiceStyle.modern()
-
factory
Properties
- accentColor → PdfColor
-
final
- backgroundColor → PdfColor
-
final
- bodyFontSize → double
-
final
- bodyTextStyle → TextStyle
-
no setter
- boldBodyTextStyle → TextStyle
-
no setter
- boldFont → Font?
-
final
-
fontFallback
→ List<
Font> -
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerStyle → HeaderStyle?
-
final
- italicFont → Font?
-
final
-
labels
→ Map<
String, String> ? -
final
- localization → InvoiceLocalization
-
final
- monetaryPolicy → MonetaryPolicy
-
final
- mutedTextColor → PdfColor
-
final
- pageFormat → PdfPageFormat
-
final
- pageMargin → EdgeInsets
-
final
- primaryColor → PdfColor
-
final
- primaryFont → Font?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor → PdfColor
-
final
- signatureImage → Uint8List?
-
final
- signatureLabel → String?
-
final
- smallFontSize → double
-
final
- smallTextStyle → TextStyle
-
no setter
- subtitleFontSize → double
-
final
- subtitleTextStyle → TextStyle
-
no setter
- tableStyle → TableStyle?
-
final
- textColor → PdfColor
-
final
- textDirection → TextDirection
-
no setter
- themeData → ThemeData
-
no setter
- titleFontSize → double
-
final
- titleTextStyle → TextStyle
-
no setter
- watermarkAngle → double
-
final
- watermarkImage → Uint8List?
-
final
- watermarkOpacity → double
-
final
- watermarkText → String?
-
final
Methods
-
copyWith(
{PdfColor? primaryColor, PdfColor? secondaryColor, PdfColor? accentColor, PdfColor? backgroundColor, PdfColor? textColor, PdfColor? mutedTextColor, Object? primaryFont = copyWithUnset, Object? boldFont = copyWithUnset, Object? italicFont = copyWithUnset, List< Font> ? fontFallback, double? titleFontSize, double? subtitleFontSize, double? bodyFontSize, double? smallFontSize, PdfPageFormat? pageFormat, EdgeInsets? pageMargin, Object? headerStyle = copyWithUnset, Object? tableStyle = copyWithUnset, Object? watermarkText = copyWithUnset, Object? watermarkImage = copyWithUnset, double? watermarkOpacity, double? watermarkAngle, Object? signatureImage = copyWithUnset, Object? signatureLabel = copyWithUnset, InvoiceLocalization? localization, MonetaryPolicy? monetaryPolicy, Object? labels = copyWithUnset}) → InvoiceStyle -
currencyFormatter(
InvoiceInfo info) → CurrencyFormatter -
formatDate(
DateTime value) → String -
formatNumber(
double value, {int maximumFractionDigits = 2}) → String -
formatPercentage(
double percentage) → String -
label(
String key, [String? defaultValue]) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited